
############
Introduction
############

bioticDETR - Detection Transformers for Biotic Interactions




********
Overview
********

Tools to create AI nural network models for biotic interactions.


************
Installation
************

Install from the Python Package Index (PyPI)::

    pip install bioticDETR


*************
Documentation
*************

https://bioticDETR.readthedocs.io


***********
Source Code
***********

https://github.com/IsotopeC/bioticDETR
